@@ -21,7 +21,11 @@ disclaimers of warranty.
 =cut
 
 use strict;
-use base "Bio::Das::ProServer::SourceAdaptor::Transport::generic";
+use warnings;
+use base qw(Bio::Das::ProServer::SourceAdaptor::Transport::generic);
+use File::stat;
+
+our $VERSION  = do { my @r = (q$Revision: 2.70 $ =~ /\d+/g); sprintf '%d.'.'%03d' x $#r, @r };
 
 sub _fh {
   my $self = shift;
@@ -66,13 +70,13 @@ sub query {
     my @parts = split("\t", $line);
 
     my $flag = 0;
-    if($cmp eq "=") {
+    if($cmp eq '=') {
       $flag = 1 if($parts[$field] eq $value);
 
-    } elsif($cmp eq "lceq") {
+    } elsif($cmp eq 'lceq') {
       $flag = 1 if(lc($parts[$field]) eq lc($value));
 
-    } elsif($cmp eq "like") {
+    } elsif($cmp eq 'like') {
       $flag = 1 if($parts[$field] =~ /^$value$/i);
     }
 
@@ -84,6 +88,16 @@ sub query {
   return $ref;
 }
 
+=head2 last_modified : machine time of last data change
+
+  $dbitransport->last_modified();
+
+=cut
+sub last_modified {
+  my $self = shift;
+  return stat($self->_fh())->mtime;
+}
+
 =head2 DESTROY : object destructor - disconnect filehandle
 
   Generally not directly invoked, but if you really want to - 
